# LiteFlowNet

## Original code

- LiteFlowNet: [https://github.com/twhui/LiteFlowNet](https://github.com/twhui/LiteFlowNet)
- LiteFlowNet2: [https://github.com/twhui/LiteFlowNet2](https://github.com/twhui/LiteFlowNet2)
- LiteFlowNet3: [https://github.com/twhui/LiteFlowNet3](https://github.com/twhui/LiteFlowNet3)

## Code licenses

See

- [LICENSE_LFN1](LICENSE_LFN1).
- [LICENSE_LFN2](LICENSE_LFN2).
- [LICENSE_LFN3](LICENSE_LFN3).

The warping layer comes from IRR (https://github.com/visinf/irr). See [LICENSE_IRR](LICENSE_IRR).

## Pretrained weights license

Not specified.

## Citation

### LiteFlowNet

```
@InProceedings{hui18liteflownet,    
 author = {Tak-Wai Hui and Xiaoou Tang and Chen Change Loy},    
 title = {{LiteFlowNet: A Lightweight Convolutional Neural Network for Optical Flow Estimation}},    
 booktitle = {{Proceedings of IEEE Conference on Computer Vision and Pattern Recognition (CVPR)}},    
 year = {2018},  
 pages = {8981--8989},
 url = {http://mmlab.ie.cuhk.edu.hk/projects/LiteFlowNet/} 
}
```

### LiteFlowNet2

```
@InProceedings{hui20liteflownet2,    
 author = {Tak-Wai Hui and Xiaoou Tang and Chen Change Loy},    
 title = {{A Lightweight Optical Flow CNN - Revisiting Data Fidelity and Regularization}}, 
 journal = {{IEEE Transactions on Pattern Analysis and Machine Intelligence}},
 year = {2020},    
 url = {http://mmlab.ie.cuhk.edu.hk/projects/LiteFlowNet/} 
}
```

### LiteFlowNet3

```
@InProceedings{hui20liteflownet3,    
 author = {Tak-Wai Hui and Chen Change Loy},    
 title = {{LiteFlowNet3: Resolving Correspondence Ambiguity for More Accurate Optical Flow Estimation}}, 
 journal = {{Proceedings of the European Conference on Computer Vision (ECCV)}},
 year = {2020},    
 pages = {169--184},
}
```
